{% extends "admin/base.html" %}
{% load i18n %}

{% block extrahead %}
<script type="text/javascript" src="{{ MEDIA_URL}}/js/tiny_mce/tiny_mce.js"></script>
<script type="text/javascript">
    tinyMCE.init({
            mode : "textareas",
            theme : "advanced"
    });
    </script>
{% endblock %}

{% block title %}{{ title }} | {% trans 'Django site admin' %}{% endblock %}

{% block branding %}
<h1 id="site-name">{% trans 'Django administration' %}</h1>
{% endblock %}

{% block nav-global %}{% endblock %}
